@@ -72,6 +72,16 @@ brasero_track_stream_set_source_real (BraseroTrackStream *track,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_track_stream_set_source:
+ * @track: a #BraseroTrackStream
+ * @uri: a #gchar
+ *
+ * Sets the stream (song or video) uri. 
+ *
+ * Return value: a #BraseroBurnResult. BRASERO_BURN_OK if it is successful.
+ **/
+
 BraseroBurnResult
 brasero_track_stream_set_source (BraseroTrackStream *track,
 				 const gchar *uri)
@@ -93,6 +103,15 @@ brasero_track_stream_set_source (BraseroTrackStream *track,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_track_stream_get_format:
+ * @track: a #BraseroTrackStream
+ *
+ * This function returns the format of the stream.
+ *
+ * Return value: a #BraseroStreamFormat.
+ **/
+
 BraseroStreamFormat
 brasero_track_stream_get_format (BraseroTrackStream *track)
 {
@@ -120,6 +139,16 @@ brasero_track_stream_set_format_real (BraseroTrackStream *track,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_track_stream_set_format:
+ * @track: a #BraseroTrackStream
+ * @format: a #BraseroStreamFormat
+ *
+ * Sets the format of the stream.
+ *
+ * Return value: a #BraseroBurnResult. BRASERO_BURN_OK if it is successful.
+ **/
+
 BraseroBurnResult
 brasero_track_stream_set_format (BraseroTrackStream *track,
 				 BraseroStreamFormat format)
@@ -163,6 +192,19 @@ brasero_track_stream_set_boundaries_real (BraseroTrackStream *track,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_track_stream_set_boundaries:
+ * @track: a #BraseroTrackStream
+ * @start: a #gint64 or -1 to ignore
+ * @end: a #gint64 or -1 to ignore
+ * @gap: a #gint64 or -1 to ignore
+ *
+ * Sets the boundaries of the stream (where it starts, ends in the file;
+ * how long is the gap with the next track) in nano seconds.
+ *
+ * Return value: a #BraseroBurnResult. BRASERO_BURN_OK if it is successful.
+ **/
+
 BraseroBurnResult
 brasero_track_stream_set_boundaries (BraseroTrackStream *track,
 				     gint64 start,
@@ -186,6 +228,17 @@ brasero_track_stream_set_boundaries (BraseroTrackStream *track,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_track_stream_get_source:
+ * @track: a #BraseroTrackStream
+ * @uri: a #gboolean
+ *
+ * This function returns the path or the URI (if @uri is TRUE)
+ * of the stream (song or video file).
+ *
+ * Return value: a #gchar.
+ **/
+
 gchar *
 brasero_track_stream_get_source (BraseroTrackStream *track,
 				 gboolean uri)
@@ -201,6 +254,15 @@ brasero_track_stream_get_source (BraseroTrackStream *track,
 		return brasero_string_get_localpath (priv->uri);
 }
 
+/**
+ * brasero_track_stream_get_gap:
+ * @track: a #BraseroTrackStream
+ *
+ * This function returns length of the gap (in nano seconds).
+ *
+ * Return value: a #guint64.
+ **/
+
 guint64
 brasero_track_stream_get_gap (BraseroTrackStream *track)
 {
@@ -212,6 +274,15 @@ brasero_track_stream_get_gap (BraseroTrackStream *track)
 	return priv->gap;
 }
 
+/**
+ * brasero_track_stream_get_start:
+ * @track: a #BraseroTrackStream
+ *
+ * This function returns start time in the stream (in nano seconds).
+ *
+ * Return value: a #guint64.
+ **/
+
 guint64
 brasero_track_stream_get_start (BraseroTrackStream *track)
 {
@@ -223,6 +294,15 @@ brasero_track_stream_get_start (BraseroTrackStream *track)
 	return priv->start;
 }
 
+/**
+ * brasero_track_stream_get_end:
+ * @track: a #BraseroTrackStream
+ *
+ * This function returns end time in the stream (in nano seconds).
+ *
+ * Return value: a #guint64.
+ **/
+
 guint64
 brasero_track_stream_get_end (BraseroTrackStream *track)
 {
@@ -234,6 +314,18 @@ brasero_track_stream_get_end (BraseroTrackStream *track)
 	return priv->end;
 }
 
+/**
+ * brasero_track_stream_get_length:
+ * @track: a #BraseroTrackStream
+ * @length: a #guint64
+ *
+ * This function returns the length of the stream (in nano seconds)
+ * taking into account the start and end time as well as the length
+ * of the gap. It stores it in @length.
+ *
+ * Return value: a #BraseroBurnResult. BRASERO_BURN_OK if @length was set.
+ **/
+
 BraseroBurnResult
 brasero_track_stream_get_length (BraseroTrackStream *track,
 				 guint64 *length)
@@ -258,18 +350,35 @@ brasero_track_stream_get_size (BraseroTrack *track,
 			       goffset *block_size)
 {
 	BraseroTrackStreamPrivate *priv;
+	BraseroStreamFormat format;
 
 	priv = BRASERO_TRACK_STREAM_PRIVATE (track);
 
-	if (blocks) {
-		guint64 length = 0;
+	format = brasero_track_stream_get_format (BRASERO_TRACK_STREAM (track));
+	if (!BRASERO_STREAM_FORMAT_HAS_VIDEO (format)) {
+		if (blocks) {
+			guint64 length = 0;
 
-		brasero_track_stream_get_length (BRASERO_TRACK_STREAM (track), &length);
-		*blocks = length * 75LL / 1000000000LL;
+			brasero_track_stream_get_length (BRASERO_TRACK_STREAM (track), &length);
+			*blocks = length * 75LL / 1000000000LL;
+		}
+
+		if (block_size)
+			*block_size = 2352;
 	}
+	else {
+		if (blocks) {
+			guint64 length = 0;
 
-	if (block_size)
-		*block_size = 2352;
+			/* This is based on a simple formula:
+			 * 4700000000 bytes means 2 hours */
+			brasero_track_stream_get_length (BRASERO_TRACK_STREAM (track), &length);
+			*blocks = length * 47LL / 72000LL / 2048LL;
+		}
+
+		if (block_size)
+			*block_size = 2048;
+	}
 
 	return BRASERO_BURN_OK;
 }
@@ -294,7 +403,7 @@ brasero_track_stream_get_status (BraseroTrack *track,
 	return BRASERO_BURN_OK;
 }
 
-static BraseroTrackDataType
+static BraseroBurnResult
 brasero_track_stream_get_track_type (BraseroTrack *track,
 				     BraseroTrackType *type)
 {
@@ -302,13 +411,10 @@ brasero_track_stream_get_track_type (BraseroTrack *track,
 
 	priv = BRASERO_TRACK_STREAM_PRIVATE (track);
 
-	if (!type)
-		return BRASERO_TRACK_TYPE_STREAM;
-
 	brasero_track_type_set_has_stream (type);
 	brasero_track_type_set_stream_format (type, priv->format);
 
-	return BRASERO_TRACK_TYPE_STREAM;
+	return BRASERO_BURN_OK;
 }
 
 static void
@@ -348,6 +454,17 @@ brasero_track_stream_class_init (BraseroTrackStreamClass *klass)
 	klass->set_boundaries = brasero_track_stream_set_boundaries_real;
 }
 
+/**
+ * brasero_track_stream_new:
+ *
+ *  Creates a new #BraseroTrackStream object.
+ *
+ * This type of tracks is used to burn audio or
+ * video files.
+ *
+ * Return value: a #BraseroTrackStream object.
+ **/
+
 BraseroTrackStream *
 brasero_track_stream_new (void)
 {
