@@ -337,7 +337,7 @@ brasero_image_format_get_FILE_info (const gchar *ptr,
 	gchar *path = NULL;
 	gint64 start = 0;
 	GFileInfo *info;
-	GFile *file;
+	GFile *file = NULL;
 	gchar *tmp;
 
 	/* get the path and skip it */
@@ -396,6 +396,8 @@ stat_end:
 		file = g_file_new_for_commandline_arg (img_uri);
 		g_free (img_uri);
 	}
+	else
+		return FALSE;
 
 	g_free (path);
 
@@ -512,6 +514,49 @@ brasero_image_format_get_cdrdao_size (gchar *uri,
 	return TRUE;
 }
 
+gboolean
+brasero_image_format_cue_bin_byte_swap (gchar *uri,
+					GCancellable *cancel,
+					GError **error)
+{
+	GFile *file;
+	gchar *line;
+	GFileInputStream *input;
+	GDataInputStream *stream;
+	gboolean is_audio = FALSE;
+	gboolean is_binary = FALSE;
+
+	file = g_file_new_for_uri (uri);
+	input = g_file_read (file, cancel, error);
+
+	if (!input) {
+		g_object_unref (file);
+		return FALSE;
+	}
+
+	stream = g_data_input_stream_new (G_INPUT_STREAM (input));
+	g_object_unref (input);
+
+	while ((line = g_data_input_stream_read_line (stream, NULL, cancel, error))) {
+		const gchar *ptr;
+		
+		if ((ptr = strstr (line, "FILE"))) {
+			if (strstr (ptr, "BINARY"))
+				is_binary = TRUE;
+		}
+		else if ((ptr = strstr (line, "TRACK"))) {
+			if (strstr (ptr, "AUDIO"))
+				is_audio = TRUE;
+		}
+		g_free (line);
+	}
+
+	g_object_unref (stream);
+	g_object_unref (file);
+
+	return is_binary && is_audio;
+}
+
 /**
  * .cue can use various data files but have to use them ALL. So we don't need
  * to care about a start/size address. We just go through the whole file and
@@ -547,12 +592,12 @@ brasero_image_format_get_cue_size (gchar *uri,
 
 		if ((ptr = strstr (line, "FILE"))) {
 			GFileInfo *info;
-			GFile *file_img;
 			gchar *file_path;
+			GFile *file_img = NULL;
 
 			ptr += 4;
 
-			/* get the path */
+			/* get the path (NOTE: if ptr is NULL file_path as well) */
 			ptr = brasero_image_format_read_path (ptr, &file_path);
 			if (!ptr) {
 				g_object_unref (stream);
@@ -835,7 +880,7 @@ brasero_image_format_get_default_path (BraseroImageFormat format)
 gchar *
 brasero_image_format_fix_path_extension (BraseroImageFormat format,
 					 gboolean check_existence,
-					 gchar *path)
+					 const gchar *path)
 {
 	gchar *dot;
 	guint i = 0;
