@@ -809,6 +809,8 @@ typedef struct _BraseroIOMetadataTask BraseroIOMetadataTask;
 struct _BraseroIOMetadataCached {
 	guint64 last_modified;
 	BraseroMetadataInfo *info;
+
+	guint missing_codec_used:1;
 };
 typedef struct _BraseroIOMetadataCached BraseroIOMetadataCached;
 
@@ -867,7 +869,6 @@ brasero_io_set_metadata_attributes (GFileInfo *info,
 
 	g_file_info_set_attribute_boolean (info, BRASERO_IO_HAS_VIDEO, metadata->has_video);
 	g_file_info_set_attribute_boolean (info, BRASERO_IO_IS_SEEKABLE, metadata->is_seekable);
-
 	if (metadata->snapshot)
 		g_file_info_set_attribute_object (info, BRASERO_IO_THUMBNAIL, G_OBJECT (metadata->snapshot));
 
@@ -952,6 +953,7 @@ brasero_io_wait_for_metadata (BraseroIO *self,
 			      GCancellable *cancel,
 			      GFileInfo *info,
 			      BraseroMetadata *metadata,
+			      BraseroMetadataFlag flags,
 			      BraseroMetadataInfo *meta_info)
 {
 	gboolean result;
@@ -988,6 +990,8 @@ brasero_io_wait_for_metadata (BraseroIO *self,
 			cached->info = g_new0 (BraseroMetadataInfo, 1);
 			brasero_metadata_get_result (metadata, cached->info, NULL);
 
+			cached->missing_codec_used = (flags & BRASERO_METADATA_FLAG_MISSING) != 0;
+
 			g_queue_push_head (priv->meta_buffer, cached);
 			if (g_queue_get_length (priv->meta_buffer) > MAX_BUFFERED_META) {
 				cached = g_queue_pop_tail (priv->meta_buffer);
@@ -1051,15 +1055,24 @@ brasero_io_get_metadata_info (BraseroIO *self,
 		cached = node->data;
 		last_modified = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_STANDARD_SIZE);
 		if (last_modified == cached->last_modified) {
+			gboolean refresh_cache = FALSE;
+
+			if (flags & BRASERO_METADATA_FLAG_MISSING) {
+				/* This cached result may indicate an error and
+				 * this error could be related to the fact that
+				 * it was not first looked for with missing
+				 * codec detection. */
+				if (!cached->missing_codec_used)
+					refresh_cache = TRUE;
+			}
+
 			if (flags & BRASERO_METADATA_FLAG_THUMBNAIL) {
 				/* If there isn't any snapshot retry */
-				if (cached->info->snapshot) {
-					brasero_metadata_info_copy (meta_info, cached->info);
-					g_mutex_unlock (priv->lock_metadata);
-					return TRUE;
-				}
+				if (!cached->info->snapshot)
+					refresh_cache = TRUE;
 			}
-			else {
+
+			if (!refresh_cache) {
 				brasero_metadata_info_copy (meta_info, cached->info);
 				g_mutex_unlock (priv->lock_metadata);
 				return TRUE;
@@ -1086,6 +1099,7 @@ brasero_io_get_metadata_info (BraseroIO *self,
 					     cancel,
 					     info,
 					     metadata,
+					     flags,
 					     meta_info);
 }
 
@@ -1637,8 +1651,8 @@ brasero_io_get_file_count_process_file (BraseroIO *self,
 				if (!brasero_io_get_file_count_process_playlist (self, cancel, data, child_uri))
 					data->files_invalid ++;
 			}
-
-			data->files_invalid ++;
+			else
+				data->files_invalid ++;
 		}
 
 #endif
@@ -1744,8 +1758,8 @@ brasero_io_get_file_count_start (BraseroIO *self,
 				  (data->job.options & BRASERO_IO_INFO_FOLLOW_SYMLINK)?G_FILE_QUERY_INFO_NONE:G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,	/* follow symlinks by default*/
 				  cancel,
 				  NULL);
-
 	data->files_num ++;
+
 	if (!info) {
 		g_object_unref (file);
 		data->files_invalid ++;
@@ -1795,7 +1809,8 @@ brasero_io_get_file_count_thread (BraseroAsyncTaskManager *manager,
 		brasero_io_get_file_count_process_directory (BRASERO_IO (manager), cancel, data);
 		return BRASERO_ASYNC_TASK_RESCHEDULE;
 	}
-	else if (!data->uris) {
+
+	if (!data->uris) {
 		info = g_file_info_new ();
 
 		/* set GFileInfo information */
