@@ -124,50 +124,6 @@ brasero_file_chooser_class_init (BraseroFileChooserClass *klass)
 	object_class->finalize = brasero_file_chooser_finalize;
 }
 
-static void
-brasero_file_chooser_paned_destroy (GObject *object,
-                                                      gpointer NULL_data)
-{
-	if (GPOINTER_TO_INT (g_object_get_data (object, "is-stock-file-chooser")))
-		brasero_setting_set_value (brasero_setting_get_default (),
-		                           BRASERO_SETTING_STOCK_FILE_CHOOSER_PERCENT,
-		                           g_object_get_data (object, "position-percent"));
-	else
-		brasero_setting_set_value (brasero_setting_get_default (),
-		                           BRASERO_SETTING_BRASERO_FILE_CHOOSER_PERCENT,
-		                           g_object_get_data (object, "position-percent"));
-}
-
-static void
-brasero_file_chooser_paned_map_event (GtkWidget *widget,
-                                      GdkEvent *event,
-                                      gpointer NULL_data)
-{
-	gint position;
-	gpointer percent;
-	GtkWidget *toplevel;
-
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (widget));
-	if (G_TYPE_FROM_INSTANCE (toplevel) == GTK_TYPE_FILE_CHOOSER_DIALOG) {
-		g_object_set_data (G_OBJECT (widget), "is-stock-file-chooser", GINT_TO_POINTER (1));
-		brasero_setting_get_value (brasero_setting_get_default (),
-		                           BRASERO_SETTING_STOCK_FILE_CHOOSER_PERCENT,
-		                           &percent);
-	}
-	else
-		brasero_setting_get_value (brasero_setting_get_default (),
-		                           BRASERO_SETTING_BRASERO_FILE_CHOOSER_PERCENT,
-		                           &percent);
-
-	if (GPOINTER_TO_INT (percent) < 0) {
-		/* No value so set something sane */
-		percent = GINT_TO_POINTER (30);
-	}
-
-	position = widget->allocation.width * GPOINTER_TO_INT (percent) / 10000;
-	gtk_paned_set_position (GTK_PANED (widget), position);
-}
-
 static void
 brasero_file_chooser_position_percent (GObject *object,
                                        gint width,
@@ -183,7 +139,14 @@ brasero_file_chooser_position_percent (GObject *object,
 	else
 		percent /= width;
 
-	g_object_set_data (object, "position-percent", GINT_TO_POINTER (percent));
+	if (GPOINTER_TO_INT (g_object_get_data (object, "is-stock-file-chooser")))
+		brasero_setting_set_value (brasero_setting_get_default (),
+		                           BRASERO_SETTING_STOCK_FILE_CHOOSER_PERCENT,
+		                           GINT_TO_POINTER (percent));
+	else
+		brasero_setting_set_value (brasero_setting_get_default (),
+		                           BRASERO_SETTING_BRASERO_FILE_CHOOSER_PERCENT,
+		                           GINT_TO_POINTER (percent));
 }
 
 static void
@@ -191,26 +154,61 @@ brasero_file_chooser_position_changed (GObject *object,
                                        GParamSpec *param_spec,
                                        gpointer NULL_data)
 {
+	GtkAllocation allocation = {0, 0};
 	gint position;
-	gint width;
 
+	gtk_widget_get_allocation (GTK_WIDGET (object), &allocation);
 	position = gtk_paned_get_position (GTK_PANED (object));
-	width = GTK_WIDGET (object)->allocation.width;
-	brasero_file_chooser_position_percent (object, width, position);
+	brasero_file_chooser_position_percent (object, allocation.width, position);
 }
 
 static void
-brasero_file_chooser_allocation_changed (GObject *object,
+brasero_file_chooser_allocation_changed (GtkWidget *widget,
                                          GtkAllocation *allocation,
                                          gpointer NULL_data)
 {
 	gint position;
 	gint width;
 
-	position = gtk_paned_get_position (GTK_PANED (object));
+	/* See if it's the first allocation. If so set the position and don't
+	 * save it */
+	if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "position_set")) == FALSE) {
+		gpointer percent;
+		GtkWidget *toplevel;
+
+		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (widget));
+		if (G_TYPE_FROM_INSTANCE (toplevel) == GTK_TYPE_FILE_CHOOSER_DIALOG) {
+			g_object_set_data (G_OBJECT (widget), "is-stock-file-chooser", GINT_TO_POINTER (1));
+			brasero_setting_get_value (brasero_setting_get_default (),
+				                   BRASERO_SETTING_STOCK_FILE_CHOOSER_PERCENT,
+				                   &percent);
+		}
+		else
+			brasero_setting_get_value (brasero_setting_get_default (),
+				                   BRASERO_SETTING_BRASERO_FILE_CHOOSER_PERCENT,
+				                   &percent);
+
+		if (GPOINTER_TO_INT (percent) < 0) {
+			/* No value so set something sane */
+			percent = GINT_TO_POINTER (30);
+		}
+
+		position = allocation->width * GPOINTER_TO_INT (percent) / 10000;
+		gtk_paned_set_position (GTK_PANED (widget), position);
+		g_object_set_data (G_OBJECT (widget), "position_set", GINT_TO_POINTER (TRUE));
+
+		/* Don't connect to position signal until it was first allocated */
+		g_signal_connect (widget,
+		                  "notify::position",
+		                  G_CALLBACK (brasero_file_chooser_position_changed),
+		                  NULL);
+		return;
+	}
+
+	position = gtk_paned_get_position (GTK_PANED (widget));
 	width = allocation->width;
 
-	brasero_file_chooser_position_percent (object, width, position);
+	brasero_file_chooser_position_percent (G_OBJECT (widget), width, position);
 }
 
 void
@@ -279,25 +277,12 @@ brasero_file_chooser_customize (GtkWidget *widget, gpointer null_data)
 					 TRUE);
 			g_object_unref (left);
 
-			g_signal_connect (widget,
-			                  "notify::position",
-			                  G_CALLBACK (brasero_file_chooser_position_changed),
-			                  NULL);
-
 			g_signal_connect (widget,
 			                  "size-allocate",
 			                  G_CALLBACK (brasero_file_chooser_allocation_changed),
 			                  NULL);
-
-			g_signal_connect (widget,
-			                  "destroy",
-			                  G_CALLBACK (brasero_file_chooser_paned_destroy),
-			                  NULL);
-			g_signal_connect (widget,
-			                  "map-event",
-			                  G_CALLBACK (brasero_file_chooser_paned_map_event),
-			                  NULL);
 		}
+
 		gtk_container_foreach (GTK_CONTAINER (widget),
 				       brasero_file_chooser_customize,
 				       NULL);
