@@ -218,7 +218,13 @@ brasero_project_manager_new_cover_cb (GtkAction *action,
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
 	dialog = brasero_jacket_edit_dialog_new (toplevel, &edit);
-	gtk_dialog_run (GTK_DIALOG (dialog));
+
+	/* This strange hack is a way to workaround #568358.
+	 * At one point we'll need to hide the dialog which means it
+	 * will anwer with a GTK_RESPONSE_NONE */
+	while (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_NONE)
+		gtk_widget_show (GTK_WIDGET (dialog));
+
 	gtk_widget_destroy (dialog);
 }
 
@@ -284,7 +290,8 @@ brasero_project_manager_set_statusbar (BraseroProjectManager *manager,
 								   "No file can be added (%i selected files)",
 								   files_num),
 							 files_num);
-		else if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO)
+		else if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO
+		     ||  manager->priv->type == BRASERO_PROJECT_TYPE_VIDEO)
 			status_string = g_strdup_printf (ngettext ("No file is supported (%i selected file)",
 								   "No file is supported (%i selected files)",
 								   files_num),
@@ -349,7 +356,7 @@ brasero_project_manager_selected_uris_preview (gpointer data)
 								   brasero_project_manager_size_preview,
 								   NULL,
 								   NULL);
-    
+
 	for (iter = manager->priv->selected; iter && *iter; iter ++)
 		list = g_slist_prepend (list, *iter);
 
@@ -511,8 +518,43 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 	if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO
 	||  manager->priv->type == BRASERO_PROJECT_TYPE_DATA
 	||  manager->priv->type == BRASERO_PROJECT_TYPE_VIDEO) {
-		if (!brasero_project_confirm_switch (BRASERO_PROJECT (manager->priv->project)))
+		BraseroBurnResult result;
+		gboolean keep_files = FALSE;
+
+		if (type == BRASERO_PROJECT_TYPE_AUDIO
+		||  type == BRASERO_PROJECT_TYPE_DATA
+		||  type == BRASERO_PROJECT_TYPE_VIDEO) {
+			if (manager->priv->type != type
+			&& (((manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO ||
+			      manager->priv->type == BRASERO_PROJECT_TYPE_VIDEO) &&
+			     type == BRASERO_PROJECT_TYPE_DATA)
+			||  manager->priv->type == BRASERO_PROJECT_TYPE_DATA))
+				keep_files = TRUE;
+		}
+
+		result = brasero_project_confirm_switch (BRASERO_PROJECT (manager->priv->project), keep_files);
+		if (result == BRASERO_BURN_CANCEL)
 			return;
+
+		if (result == BRASERO_BURN_RETRY) {
+			if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO
+			||  manager->priv->type == BRASERO_PROJECT_TYPE_VIDEO)
+				type = brasero_project_convert_to_data (BRASERO_PROJECT (manager->priv->project));
+			else if (manager->priv->type == BRASERO_PROJECT_TYPE_DATA) {
+				BraseroProjectType new_type;
+
+				/* Keep type untouched */
+				new_type = brasero_project_convert_to_stream (BRASERO_PROJECT (manager->priv->project),
+									      type == BRASERO_PROJECT_TYPE_VIDEO);
+				if (new_type == BRASERO_PROJECT_TYPE_INVALID)
+					type = new_type;
+			}
+
+			if (type != BRASERO_PROJECT_TYPE_INVALID)
+				reset = FALSE;
+			else
+				reset = TRUE;
+		}
 	}
 
 	if (manager->priv->status_ctx) {
