@@ -1,3 +1,5 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+
 /***************************************************************************
  *            project.c
  *
@@ -57,6 +59,8 @@
 #endif
 
 #include "brasero-track-data.h"
+#include "brasero-track-data-cfg.h"
+#include "brasero-track-stream-cfg.h"
 #include "brasero-session-cfg.h"
 
 /* These includes are not in the exported *.h files by 
@@ -333,10 +337,14 @@ brasero_project_get_proportion (BraseroLayoutObject *object,
 				gint *center,
 				gint *footer)
 {
+	GtkAllocation allocation;
+
 	if (!BRASERO_PROJECT (object)->priv->name_display)
 		return;
 
-	*footer = BRASERO_PROJECT (object)->priv->name_display->parent->allocation.height;
+	gtk_widget_get_allocation (gtk_widget_get_parent (BRASERO_PROJECT (object)->priv->name_display),
+				   &allocation);
+	*footer = allocation.height;
 }
 
 static void
@@ -380,7 +388,8 @@ brasero_project_set_add_button_state (BraseroProject *project)
 		return;
 
 	widget = gtk_bin_get_child (GTK_BIN (widget));
-	GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (widget, TRUE);
+
 	gtk_window_set_default (GTK_WINDOW (toplevel), widget);
 }
 
@@ -578,7 +587,7 @@ brasero_utils_disc_style_changed_cb (GtkWidget *widget,
 {
 	/* The widget (a treeview here) needs to be realized to get proper style */
 	gtk_widget_realize (widget);
-	gtk_widget_modify_bg (event_box, GTK_STATE_NORMAL, &widget->style->base[GTK_STATE_NORMAL]);
+	gtk_widget_modify_bg (event_box, GTK_STATE_NORMAL, &gtk_widget_get_style (widget)->base[GTK_STATE_NORMAL]);
 }
 
 static void
@@ -587,7 +596,7 @@ brasero_utils_disc_realized_cb (GtkWidget *event_box,
 {
 	/* The widget (a treeview here) needs to be realized to get proper style */
 	gtk_widget_realize (textview);
-	gtk_widget_modify_bg (event_box, GTK_STATE_NORMAL, &textview->style->base[GTK_STATE_NORMAL]);
+	gtk_widget_modify_bg (event_box, GTK_STATE_NORMAL, &gtk_widget_get_style (textview)->base[GTK_STATE_NORMAL]);
 
 	g_signal_handlers_disconnect_by_func (textview,
 					      brasero_utils_disc_style_changed_cb,
@@ -873,7 +882,8 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 
 		status = brasero_status_new ();
 		brasero_burn_session_get_status (BRASERO_BURN_SESSION (session), status);
-		if (brasero_status_get_result (status) == BRASERO_BURN_NOT_READY) {
+		if (brasero_status_get_result (status) == BRASERO_BURN_NOT_READY
+		||  brasero_status_get_result (status) == BRASERO_BURN_RUNNING) {
 			cursor = gdk_cursor_new (GDK_WATCH);
 			gdk_window_set_cursor (window, cursor);
 			gdk_cursor_unref (cursor);
@@ -897,7 +907,7 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 	 * that means that file selection is not empty */
 
 	/* Clean any message */
-	brasero_notify_message_remove (BRASERO_NOTIFY (project->priv->message),
+	brasero_notify_message_remove (project->priv->message,
 				       BRASERO_NOTIFY_CONTEXT_SIZE);
 
 	if (valid == BRASERO_SESSION_EMPTY) {
@@ -924,16 +934,15 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 		&& brasero_session_span_possible (BRASERO_SESSION_SPAN (session)) == BRASERO_BURN_RETRY) {
 			GtkWidget *message;
 
-			message = brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
+			message = brasero_notify_message_add (project->priv->message,
 							      _("Would you like to burn the selection of files across several media?"),
 							      _("The project is too large for the disc even with the overburn option."),
 							      -1,
 							      BRASERO_NOTIFY_CONTEXT_SIZE);
-			brasero_notify_button_add (BRASERO_NOTIFY (project->priv->message),
-						   BRASERO_DISC_MESSAGE (message),
-						   _("_Burn Several Discs"),
-						   _("Burn the selection of files across several media"),
-						   GTK_RESPONSE_OK);
+			gtk_widget_set_tooltip_text (gtk_info_bar_add_button (GTK_INFO_BAR (message),
+									      _("_Burn Several Discs"),
+								    	      GTK_RESPONSE_OK),
+						     _("Burn the selection of files across several media"));
 
 			g_signal_connect (message,
 					  "response",
@@ -941,7 +950,7 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 					  project);
 		}
 		else
-			brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
+			brasero_notify_message_add (project->priv->message,
 						    _("Please choose another CD or DVD or insert a new one."),
 						    _("The project is too large for the disc even with the overburn option."),
 						    -1,
@@ -952,18 +961,17 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 
 		project->priv->empty = FALSE;
 		project->priv->oversized = TRUE;
-		message = brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
+		message = brasero_notify_message_add (project->priv->message,
 						      _("Would you like to burn beyond the disc's reported capacity?"),
 						      _("The project is too large for the disc and you must remove files from it."
 							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognized and therefore needs the overburn option."
 							"\nNote: This option might cause failure."),
 						      -1,
 						      BRASERO_NOTIFY_CONTEXT_SIZE);
-		brasero_notify_button_add (BRASERO_NOTIFY (project->priv->message),
-					   BRASERO_DISC_MESSAGE (message),
-					   _("_Overburn"),
-					   _("Burn beyond the disc's reported capacity"),
-					   GTK_RESPONSE_OK);
+		gtk_widget_set_tooltip_text (gtk_info_bar_add_button (GTK_INFO_BAR (message),
+								      _("_Overburn"),
+							    	      GTK_RESPONSE_OK),
+					     _("Burn beyond the disc's reported capacity"));
 
 		g_signal_connect (message,
 				  "response",
@@ -972,7 +980,7 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 	}
 	else if (valid == BRASERO_SESSION_NO_OUTPUT) {
 		project->priv->empty = FALSE;
-		brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
+		brasero_notify_message_add (project->priv->message,
 					    _("Please insert a writable CD or DVD."),
 					    NULL,
 					    -1,
@@ -980,14 +988,14 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 	}
 	else if (valid == BRASERO_SESSION_NOT_SUPPORTED) {
 		project->priv->empty = FALSE;
-		brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
+		brasero_notify_message_add (project->priv->message,
 					    _("Please replace the disc with a supported CD or DVD."),
 					    NULL,
 					    -1,
 					    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
 	else if (valid == BRASERO_SESSION_NO_CD_TEXT) {
-		brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
+		brasero_notify_message_add (project->priv->message,
 					    _("No track information (artist, title, ...) will be written to the disc."),
 					    _("This is not supported by the current active burning backend."),
 					    -1,
@@ -997,7 +1005,7 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 	     &&  brasero_medium_selection_get_media_num (BRASERO_MEDIUM_SELECTION (project->priv->selection)) == 1) {
 		/* The user may have forgotten to insert a disc so remind him of that if
 		 * there aren't any other possibility in the selection */
-		brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
+		brasero_notify_message_add (project->priv->message,
 					    _("Please insert a writable CD or DVD if you don't want to write to an image file."),
 					    NULL,
 					    10000,
@@ -1286,7 +1294,7 @@ brasero_project_check_status (BraseroProject *project)
 		return BRASERO_BURN_OK;
 
         dialog = brasero_status_dialog_new (BRASERO_BURN_SESSION (project->priv->session),
-                                                                  gtk_widget_get_toplevel (GTK_WIDGET (project)));
+                                            gtk_widget_get_toplevel (GTK_WIDGET (project)));
 
 	gtk_widget_show (dialog);
         response = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1370,8 +1378,8 @@ brasero_project_list_missing (BraseroPluginErrorType type,
 	}
 	else if (type == BRASERO_PLUGIN_ERROR_MISSING_GSTREAMER_PLUGIN) {
 		g_string_append_c (string, '\n');
-		/* Translators: %s is the name of a missing Gstreamer plugin */
-		g_string_append_printf (string, _("%s (Gstreamer plugin)"), detail);
+		/* Translators: %s is the name of a missing GStreamer plugin */
+		g_string_append_printf (string, _("%s (GStreamer plugin)"), detail);
 	}
 
 	return BRASERO_BURN_OK;
@@ -1388,14 +1396,29 @@ brasero_project_check_plugins_not_ready (BraseroProject *project,
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (project));
 	gtk_widget_set_sensitive (parent, FALSE);
 
+	brasero_burn_session_set_strict_support (BRASERO_BURN_SESSION (session), TRUE);
+	result = brasero_burn_session_can_burn (session, FALSE);
+	brasero_burn_session_set_strict_support (BRASERO_BURN_SESSION (session), FALSE);
+
+	if (result == BRASERO_BURN_OK) {
+		gtk_widget_set_sensitive (parent, TRUE);
+		return result;
+	}
+
+	result = brasero_burn_session_can_burn (session, FALSE);
+	if (result != BRASERO_BURN_OK) {
+		gtk_widget_set_sensitive (parent, TRUE);
+		return result;
+	}
+
 	result = brasero_session_foreach_plugin_error (session,
 	                                               brasero_project_install_missing,
 	                                               project);
+	gtk_widget_set_sensitive (parent, TRUE);
+
 	if (result == BRASERO_BURN_CANCEL)
 		return result;
 
-	gtk_widget_set_sensitive (parent, TRUE);
-
 	if (result == BRASERO_BURN_OK)
 		return result;
 
@@ -1435,7 +1458,7 @@ brasero_project_setup_session (BraseroProject *project,
 	}
 }
 
-static gboolean
+static BraseroBurnResult
 brasero_project_drive_properties (BraseroProject *project)
 {
 	BraseroTrackType *track_type;
@@ -1452,6 +1475,7 @@ brasero_project_drive_properties (BraseroProject *project)
 
 	/* Build dialog */
 	drive = brasero_burn_session_get_burner (BRASERO_BURN_SESSION (project->priv->session));
+
 	display_name = brasero_drive_get_display_name (drive);
 	header = g_strdup_printf (_("Properties of %s"), display_name);
 	g_free (display_name);
@@ -1465,6 +1489,10 @@ brasero_project_drive_properties (BraseroProject *project)
 					      NULL);
 	g_free (header);
 
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("Burn _Several Copies"),
+			       GTK_RESPONSE_ACCEPT);
+
 	button = brasero_utils_make_button (_("_Burn"),
 					    NULL,
 					    "media-optical-burn",
@@ -1505,7 +1533,13 @@ brasero_project_drive_properties (BraseroProject *project)
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	return (answer == GTK_RESPONSE_OK);
+	if (answer == GTK_RESPONSE_OK)
+		return BRASERO_BURN_OK;
+
+	if (answer == GTK_RESPONSE_ACCEPT)
+		return BRASERO_BURN_RETRY;
+
+	return BRASERO_BURN_CANCEL;
 }
 
 static gboolean
@@ -1523,20 +1557,14 @@ brasero_project_image_properties (BraseroProject *project)
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 
-	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       GTK_STOCK_CANCEL,
+			       GTK_RESPONSE_CANCEL);
 
-	button = brasero_utils_make_button (_("_Burn"),
-					    NULL,
-					    "media-optical-burn",
-					    GTK_ICON_SIZE_BUTTON);
-	gtk_widget_show (button);
-	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
-				      button,
-				      GTK_RESPONSE_OK);
-
-	GTK_WIDGET_SET_FLAGS (button,
-	                      GTK_WIDGET_FLAGS (button)|
-	                      GTK_CAN_DEFAULT);
+	button = gtk_dialog_add_button (GTK_DIALOG (dialog),
+					_("Create _Image"),
+				       GTK_RESPONSE_OK);
+	gtk_button_set_image (GTK_BUTTON (button), gtk_image_new_from_icon_name ("iso-image-new", GTK_ICON_SIZE_BUTTON));
 
 	brasero_image_properties_set_session (BRASERO_IMAGE_PROPERTIES (dialog), project->priv->session);
 
@@ -1564,13 +1592,13 @@ brasero_project_image_properties (BraseroProject *project)
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	return (answer == GTK_RESPONSE_OK);
+	return (answer == GTK_RESPONSE_OK) ? BRASERO_BURN_OK:BRASERO_BURN_ERR;
 }
 
 void
 brasero_project_burn (BraseroProject *project)
 {
-	gboolean res = FALSE;
+	BraseroBurnResult res;
 	BraseroDisc *current_disc;
 
 	/* Check that we are ready */
@@ -1586,7 +1614,7 @@ brasero_project_burn (BraseroProject *project)
 	else
 		res = brasero_project_image_properties (project);
 
-	if (!res)
+	if (res != BRASERO_BURN_OK && res != BRASERO_BURN_RETRY)
 		return;
 
 	project->priv->is_burning = 1;
@@ -1604,8 +1632,9 @@ brasero_project_burn (BraseroProject *project)
 	brasero_uri_container_uri_selected (BRASERO_URI_CONTAINER (project));
 
 	/* now setup the burn dialog */
-	if (brasero_app_burn (brasero_app_get_default (), BRASERO_BURN_SESSION (project->priv->session)))
-		project->priv->burnt = TRUE;
+	project->priv->burnt = brasero_app_burn (brasero_app_get_default (),
+						 BRASERO_BURN_SESSION (project->priv->session),
+						 res == BRASERO_BURN_RETRY);
 
 	/* empty the stack of temporary tracks */
 	while (brasero_burn_session_pop_tracks (BRASERO_BURN_SESSION (project->priv->session)) == BRASERO_BURN_RETRY);
@@ -1631,7 +1660,13 @@ brasero_project_create_audio_cover (BraseroProject *project)
 	brasero_project_setup_session (project, BRASERO_BURN_SESSION (project->priv->session));
 	window = brasero_session_edit_cover (BRASERO_BURN_SESSION (project->priv->session),
 					     gtk_widget_get_toplevel (GTK_WIDGET (project)));
-	gtk_dialog_run (GTK_DIALOG (window));
+
+	/* This strange hack is a way to workaround #568358.
+	 * At one point we'll need to hide the dialog which means it
+	 * will anwer with a GTK_RESPONSE_NONE */
+	while (gtk_dialog_run (GTK_DIALOG (window)) == GTK_RESPONSE_NONE)
+		gtk_widget_show (GTK_WIDGET (window));
+
 	gtk_widget_destroy (window);
 }
 
@@ -1695,9 +1730,9 @@ brasero_project_reset (BraseroProject *project)
 		project->priv->session = NULL;
 	}
 
-	brasero_notify_message_remove (BRASERO_NOTIFY (project->priv->message), BRASERO_NOTIFY_CONTEXT_SIZE);
-	brasero_notify_message_remove (BRASERO_NOTIFY (project->priv->message), BRASERO_NOTIFY_CONTEXT_LOADING);
-	brasero_notify_message_remove (BRASERO_NOTIFY (project->priv->message), BRASERO_NOTIFY_CONTEXT_MULTISESSION);
+	brasero_notify_message_remove (project->priv->message, BRASERO_NOTIFY_CONTEXT_SIZE);
+	brasero_notify_message_remove (project->priv->message, BRASERO_NOTIFY_CONTEXT_LOADING);
+	brasero_notify_message_remove (project->priv->message, BRASERO_NOTIFY_CONTEXT_MULTISESSION);
 }
 
 static void
@@ -1749,6 +1784,7 @@ brasero_project_switch (BraseroProject *project, BraseroProjectType type)
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (project->priv->discs), 0);
 		brasero_medium_selection_show_media_type (BRASERO_MEDIUM_SELECTION (project->priv->selection),
 							  BRASERO_MEDIA_TYPE_WRITABLE|
+							  BRASERO_MEDIA_TYPE_FILE|
 		                                          BRASERO_MEDIA_TYPE_CD);
 	}
 	else if (type == BRASERO_PROJECT_TYPE_DATA) {
@@ -1766,8 +1802,6 @@ brasero_project_switch (BraseroProject *project, BraseroProjectType type)
 							  BRASERO_MEDIA_TYPE_FILE);
 	}
 
-	brasero_dest_selection_choose_best (BRASERO_DEST_SELECTION (project->priv->selection));
-
 	if (project->priv->current) {
 		project->priv->merge_id = brasero_disc_add_ui (project->priv->current,
 							       project->priv->manager,
@@ -1776,7 +1810,7 @@ brasero_project_switch (BraseroProject *project, BraseroProjectType type)
 						   BRASERO_BURN_SESSION (project->priv->session));
 	}
 
-	brasero_notify_message_remove (BRASERO_NOTIFY (project->priv->message), BRASERO_NOTIFY_CONTEXT_SIZE);
+	brasero_notify_message_remove (project->priv->message, BRASERO_NOTIFY_CONTEXT_SIZE);
 
 	/* update the menus */
 	action = gtk_action_group_get_action (project->priv->project_group, "Add");
@@ -1795,50 +1829,29 @@ brasero_project_switch (BraseroProject *project, BraseroProjectType type)
 }
 
 void
-brasero_project_set_audio (BraseroProject *project, GSList *uris)
+brasero_project_set_audio (BraseroProject *project)
 {
 	brasero_project_new_session (project, NULL);
 	brasero_project_switch (project, BRASERO_PROJECT_TYPE_AUDIO);
-
-	for (; uris; uris = uris->next) {
-		gchar *uri;
-
-	    	uri = uris->data;
-		brasero_disc_add_uri (project->priv->current, uri);
-	}
 }
 
 void
-brasero_project_set_data (BraseroProject *project,
-			  GSList *uris)
+brasero_project_set_data (BraseroProject *project)
 {
 	brasero_project_new_session (project, NULL);
 	brasero_project_switch (project, BRASERO_PROJECT_TYPE_DATA);
-
-	for (; uris; uris = uris->next) {
-		gchar *uri;
-
-	    	uri = uris->data;
-		brasero_disc_add_uri (project->priv->current, uri);
-	}
 }
 
 void
-brasero_project_set_video (BraseroProject *project, GSList *uris)
+brasero_project_set_video (BraseroProject *project)
 {
 	brasero_project_new_session (project, NULL);
 	brasero_project_switch (project, BRASERO_PROJECT_TYPE_VIDEO);
-
-	for (; uris; uris = uris->next) {
-		gchar *uri;
-
-	    	uri = uris->data;
-		brasero_disc_add_uri (project->priv->current, uri);
-	}
 }
 
-gboolean
-brasero_project_confirm_switch (BraseroProject *project)
+BraseroBurnResult
+brasero_project_confirm_switch (BraseroProject *project,
+				gboolean keep_files)
 {
 	GtkWidget *dialog;
 	GtkResponseType answer;
@@ -1853,10 +1866,30 @@ brasero_project_confirm_switch (BraseroProject *project)
 					     GTK_MESSAGE_WARNING);
 
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  _("If you choose to create a new project, all changes made will be lost."));
-		gtk_dialog_add_button (GTK_DIALOG (dialog),
-				       _("_Discard Changes"), GTK_RESPONSE_OK);
+							  _("If you choose to create a new empty project, all changes will be lost."));
 
+		gtk_dialog_add_button (GTK_DIALOG (dialog),
+				       _("_Discard Changes"),
+				       GTK_RESPONSE_OK);
+	}
+	else if (keep_files) {
+		if (project->priv->empty)
+			return TRUE;
+
+		dialog = brasero_app_dialog (brasero_app_get_default (),
+					     _("Do you want to discard the file selection or add it to the new project?"),
+					     GTK_BUTTONS_CANCEL,
+					     GTK_MESSAGE_WARNING);
+
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  _("If you choose to create a new empty project, the file selection will be discarded."));
+		gtk_dialog_add_button (GTK_DIALOG (dialog),
+				       _("_Discard File Selection"),
+				       GTK_RESPONSE_OK);
+
+		gtk_dialog_add_button (GTK_DIALOG (dialog),
+				       _("_Keep File Selection"),
+				       GTK_RESPONSE_ACCEPT);
 	}
 	else {
 		if (project->priv->empty)
@@ -1868,21 +1901,22 @@ brasero_project_confirm_switch (BraseroProject *project)
 					     GTK_MESSAGE_WARNING);
 
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  _("If you choose to create a new project, "
-							    "all files already added will be discarded. "
-							    "Note that files will not be deleted from their own location, "
-							    "just no longer listed here."));
+							  _("If you choose to create a new empty project, the file selection will be discarded."));
 		gtk_dialog_add_button (GTK_DIALOG (dialog),
-				       _("_Discard Project"), GTK_RESPONSE_OK);
+				       _("_Discard Project"),
+				       GTK_RESPONSE_OK);
 	}
 
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	if (answer != GTK_RESPONSE_OK)
-		return FALSE;
+	if (answer == GTK_RESPONSE_ACCEPT)
+		return BRASERO_BURN_RETRY;
 
-	return TRUE;
+	if (answer != GTK_RESPONSE_OK)
+		return BRASERO_BURN_CANCEL;
+
+	return BRASERO_BURN_OK;
 }
 
 void
@@ -2304,7 +2338,8 @@ brasero_project_register_ui (BraseroProject *project, GtkUIManager *manager)
 
 	project->priv->manager = manager;
 
-	gtk_widget_grab_focus (project->priv->name_display);
+	if (GTK_WIDGET_REALIZED (project->priv->name_display))
+		gtk_widget_grab_focus (project->priv->name_display);
 }
 
 /******************************* common to save/open ***************************/
@@ -2450,6 +2485,84 @@ brasero_project_open_session (BraseroProject *project,
 	return type;
 }
 
+BraseroProjectType
+brasero_project_convert_to_data (BraseroProject *project)
+{
+	GSList *tracks;
+	BraseroProjectType type;
+	BraseroSessionCfg *newsession;
+	BraseroTrackDataCfg *data_track;
+
+	newsession = brasero_session_cfg_new ();
+	data_track = brasero_track_data_cfg_new ();
+	brasero_burn_session_add_track (BRASERO_BURN_SESSION (newsession),
+					BRASERO_TRACK (data_track),
+					NULL);
+	g_object_unref (data_track);
+
+	tracks = brasero_burn_session_get_tracks (BRASERO_BURN_SESSION (project->priv->session));
+	for (; tracks; tracks = tracks->next) {
+		BraseroTrackStream *track;
+		gchar *uri;
+
+		track = tracks->data;
+		uri = brasero_track_stream_get_source (track, TRUE);
+		brasero_track_data_cfg_add (data_track, uri, NULL);
+		g_free (uri);
+	}
+
+	type = brasero_project_open_session (project, newsession);
+	g_object_unref (newsession);
+
+	return type;
+}
+
+BraseroProjectType
+brasero_project_convert_to_stream (BraseroProject *project,
+				   gboolean is_video)
+{
+	GSList *tracks;
+	GtkTreeIter iter;
+	BraseroProjectType type;
+	BraseroSessionCfg *newsession;
+	BraseroTrackDataCfg *data_track;
+
+	tracks = brasero_burn_session_get_tracks (BRASERO_BURN_SESSION (project->priv->session));
+	if (!tracks)
+		return BRASERO_PROJECT_TYPE_INVALID;
+
+	data_track = tracks->data;
+	if (!gtk_tree_model_get_iter_first (GTK_TREE_MODEL (data_track), &iter))
+		return BRASERO_PROJECT_TYPE_INVALID;
+
+	newsession = brasero_session_cfg_new ();
+	do {
+		gchar *uri;
+		BraseroTrackStreamCfg *track;
+
+		gtk_tree_model_get (GTK_TREE_MODEL (data_track), &iter,
+				    BRASERO_DATA_TREE_MODEL_URI, &uri,
+				    -1);
+
+		track = brasero_track_stream_cfg_new ();
+		brasero_track_stream_set_source (BRASERO_TRACK_STREAM (track), uri);
+		brasero_track_stream_set_format (BRASERO_TRACK_STREAM (track),
+						 is_video ? BRASERO_VIDEO_FORMAT_UNDEFINED:BRASERO_AUDIO_FORMAT_UNDEFINED);
+		g_free (uri);
+
+		brasero_burn_session_add_track (BRASERO_BURN_SESSION (newsession),
+						BRASERO_TRACK (track),
+						NULL);
+		g_object_unref (track);
+
+	} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (data_track), &iter));
+
+	type = brasero_project_open_session (project, newsession);
+	g_object_unref (newsession);
+
+	return type;
+}
+
 /******************************** save project *********************************/
 static void
 brasero_project_not_saved_dialog (BraseroProject *project)
